summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_container.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
commit13281e2856a2ef43bbab78c5528470309c23aa77 (patch)
tree936bcf8145dc235004c73e9fb3d6b3dca9aa370b /khtml/rendering/render_container.cpp
parente81c741bb2cf337a43524e75f22f7728ce17a343 (diff)
downloadtdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.tar.gz
tdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'khtml/rendering/render_container.cpp')
-rw-r--r--khtml/rendering/render_container.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/khtml/rendering/render_container.cpp b/khtml/rendering/render_container.cpp
index 13f17c08d..69f987477 100644
--- a/khtml/rendering/render_container.cpp
+++ b/khtml/rendering/render_container.cpp
@@ -170,11 +170,11 @@ RenderObject* RenderContainer::removeChildNode(RenderObject* oldChild)
KHTMLAssert(oldChild->parent() == this);
// So that we'll get the appropriate dirty bit set (either that a normal flow child got yanked or
// that a positioned child got yanked). We also tqrepaint, so that the area exposed when the child
// disappears gets repainted properly.
if ( document()->renderer() ) {
oldChild->setNeedsLayoutAndMinMaxRecalc();
- oldChild->tqrepaint();
+ oldChild->repaint();
// Keep our layer hierarchy updated.
oldChild->removeLayers(enclosingLayer());
@@ -170,11 +170,11 @@ RenderObject* RenderContainer::removeChildNode(RenderObject* oldChild)
KHTMLAssert(oldChild->parent() == this);
// So that we'll get the appropriate dirty bit set (either that a normal flow child got yanked or
- // that a positioned child got yanked). We also tqrepaint, so that the area exposed when the child
+ // that a positioned child got yanked). We also repaint, so that the area exposed when the child
// disappears gets repainted properly.
if ( document()->renderer() ) {